.. Sosse documentation master file, created by
   sphinx-quickstart on Mon Apr 17 13:06:50 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Sosse's documentation!
======================

.. toctree::
   :maxdepth: 2
   :caption: 🐾 Contents:

   introduction.rst
   install.rst
   administration.rst
   guides.rst
   config_file.rst
   cli.rst
   user_doc.rst
   screenshots.rst

.. toctree::
   :maxdepth: 1

   CHANGELOG.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
